#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Interfaces for casa_envoy
"""
import abc
from abc import ABC
from typing import Dict


class LauncherIF(ABC):
    """
    Generic Launcher methods.
    Should be implemented for any type of CASA processing.
    """

    @abc.abstractmethod
    def launch_casa(self):
        pass

    @abc.abstractmethod
    def run_audit(self, parameters: Dict[str, str]):
        pass


class AuditorIF(ABC):
    """
    Generic functionality implementation for auditor classes
    """

    @abc.abstractmethod
    def audit(self):
        pass


class FoundationIF(ABC):
    """
    Generic Foundation methods
    Should be implemented for any type of CASA processing that requires initial data placement
    in locations other than rawdata after download
    """

    @abc.abstractmethod
    def data_foundation(self):
        pass
